@@ -273,6 +273,7 @@ void ewkm( // Inputs ----------------------------------------------------------
 		int *maxiter, 	// Maximum number of iterations
 		double *delta, 	// Minimum change below which iteration stops
 		int *maxrestart,      // Maximum number of restarts
+		int *init,            // Initial k prototypes.
 		// Outputs ---------------------------------------------------------
 		int *iterations,	// Number of iterations
 		int *cluster, 	// Cluster assignment for each obs (nr)
@@ -297,10 +298,13 @@ void ewkm( // Inputs ----------------------------------------------------------
 	// Initialise a rand sequence.
 	srand(unif_rand() * RAND_MAX);
 
-	// Initialize the prototypes.
-
-	initPrototypes(x, nr, nc, k, centers);
+	// Initialize the prototypes. The user can pass in a list of k
+	// indicies as the row indicies for the initial protoypes. A
+	// single 0 indicates to use random initialisation.
 
+	if (*init == 0)
+	  initPrototypes(x, nr, nc, k, centers);
+	
 	// Initialize the feature weights of a cluster.
 
 	for (l = 0; l < (*k) * (*nc); l++)
@@ -313,8 +317,8 @@ void ewkm( // Inputs ----------------------------------------------------------
 	*restarts = 0;
 
 	while (++iteration <= *maxiter) {
-		//TODO Enable it for R
-		Rprintf("*");
+		//TODO Remove this for R
+		Rprintf(".");
 		dispersion = dispersion1;
 
 		updPartition(x, nr, nc, k, centers, weights, cluster);
@@ -354,8 +358,9 @@ void ewkm( // Inputs ----------------------------------------------------------
 		if (fabs(dispersion - dispersion1) / dispersion1 < *delta)
 			break;
 	}
-	//TODO Enable it for R
-	Rprintf("Clustering converged. Terminate!\n");
+
+	// Remove this for R.
+	Rprintf("Converged.\n");
 
 	// Record results in output variables for passing back to R.
 
